@@ -2,6 +2,22 @@ context("Logger")
 
 
 
+test_that("logging conditions works", {
+  e <- error("blahblah")
+
+  ln <- get_logger("test")$
+    config(NULL)$
+    set_propagate(FALSE)
+
+  lg <- get_logger_glue("test_glue")$
+    config(NULL)$
+    set_propagate(FALSE)
+
+  expect_match(ln$fatal(e), "blahblah")
+  expect_match(lg$fatal(e, "this is <{it}>", e, it = 1, conditon = e), "blahblahthis is <1>blahblah")
+})
+
+
 
 test_that("set_threshold()", {
   ml <- Logger$new("test_logger")
@@ -313,11 +329,11 @@ test_that("LoggerGlue supports custom fields", {
 
   expect_output(
     l$fatal("blah", "blubb", foo = "bar"),
-    "blahblubb.*bar\\}"
+    ".*blahblubb.*bar.*\\}"
   )
   expect_output(
     l$fatal("blah", "blubb {fizz}", foo = "bar", fizz = "buzz"),
-    "buzz.*\\{foo.*bar.*fizz.*buzz\\}$"
+    "buzz.*foo.*bar.*fizz.*buzz.*"
   )
 
   expect_output(l$fatal("a", .open = "{", .foo = "bar", fizz = "buzz"))
